gmime r1280 - trunk/gmime



Author: fejj
Date: Mon May 26 00:57:18 2008
New Revision: 1280
URL: http://svn.gnome.org/viewvc/gmime?rev=1280&view=rev

Log:
renamed some params

Modified:
   trunk/gmime/gmime-charset.c
   trunk/gmime/gmime-charset.h

Modified: trunk/gmime/gmime-charset.c
==============================================================================
--- trunk/gmime/gmime-charset.h	(original)
+++ trunk/gmime/gmime-charset.h	Mon May 26 00:57:18 2008
@@ -59,10 +59,10 @@
 } GMimeCharset;
 
 void g_mime_charset_init (GMimeCharset *charset);
-void g_mime_charset_step (GMimeCharset *charset, const char *in, size_t len);
+void g_mime_charset_step (GMimeCharset *charset, const char *inbuf, size_t inlen);
 const char *g_mime_charset_best_name (GMimeCharset *charset);
 
-const char *g_mime_charset_best (const char *in, size_t inlen);
+const char *g_mime_charset_best (const char *inbuf, size_t inlen);
 
 gboolean g_mime_charset_can_encode (GMimeCharset *mask, const char *charset,
 				    const char *text, size_t len);



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
--- trunk/gmime/gmime-charset.c	(original)
+++ trunk/gmime/gmime-charset.c	Mon May 26 00:57:18 2008
@@ -694,8 +694,8 @@
 /**
  * g_mime_charset_step:
  * @charset: charset structure
  * @in: input text buffer (must be in UTF-8)
  * @len: input buffer length
  *
  * Steps through the input buffer 1 unicode character (glyph) at a
  * time (ie, not necessarily 1 byte at a time). Bitwise 'and' our
@@ -703,10 +703,10 @@
  * limiting what charsets our @charset->mask can match.
  **/
 void
-g_mime_charset_step (GMimeCharset *charset, const char *in, size_t len)
+g_mime_charset_step (GMimeCharset *charset, const char *inbuf, size_t inlen)
 {
-	register const char *inptr = in;
-	const char *inend = in + len;
+	register const char *inptr = inbuf;
+	const char *inend = inbuf + inlen;
 	register unsigned int mask;
 	register int level;
 	
@@ -784,8 +784,8 @@
 
 /**
  * g_mime_charset_best:
  * @in: a UTF-8 text buffer
  * @inlen: length of @in
  *
  * Computes the best charset to use to encode this text buffer.
  *
@@ -793,12 +793,12 @@
  * it is US-ASCII safe.
  **/
 const char *
-g_mime_charset_best (const char *in, size_t inlen)
+g_mime_charset_best (const char *inbuf, size_t inlen)
 {
 	GMimeCharset charset;
 	
 	g_mime_charset_init (&charset);
-	g_mime_charset_step (&charset, in, inlen);
+	g_mime_charset_step (&charset, inbuf, inlen);
 	
 	return g_mime_charset_best_name (&charset);
 }
@@ -694,8 +694,8 @@
  * g_mime_charset_step:
  * @charset: charset structure
- * @in: input text buffer (must be in UTF-8)
- * @len: input buffer length
+ * @inbuf: input text buffer (must be in UTF-8)
+ * @inlen: input buffer length
  *
  * Steps through the input buffer 1 unicode character (glyph) at a
@@ -784,8 +784,8 @@
 /**
  * g_mime_charset_best:
- * @in: a UTF-8 text buffer
- * @inlen: length of @in
+ * @inbuf: a UTF-8 text buffer
+ * @inlen: input buffer length
  *
  * Computes the best charset to use to encode this text buffer.

Modified: trunk/gmime/gmime-charset.h
==============================================================================